"use client"
import { Envelope } from "@/components/svg";
import { Badge } from "@/components/ui/badge";
import { Button } from "@/components/ui/button";
import {
  DropdownMenu,
  DropdownMenuContent,
  DropdownMenuItem,
  DropdownMenuLabel,
  DropdownMenuTrigger,
} from "@/components/ui/dropdown-menu";
import shortImage from "@/public/images/all-img/admin.png";
import Link from "next/link";
import { contacts } from "./data";
import { Avatar, AvatarFallback, AvatarImage } from "@/components/ui/avatar";
import { cn } from "@/lib/utils";
import { ScrollArea } from "@/components/ui/scroll-area";
import { useState } from "react";
import { useEffect } from "react";
import { getWithToken } from "@/Helper/common";


const Inbox = () => {



  const [data, setUserData] = useState([]);
  const [totalData, setTotalData] = useState(0);

  useEffect(() => {
    fetchKycData();

  }, []);

  var apiCall = true;

  const fetchKycData = async () => {
    try {

      if (apiCall) {

        apiCall = false;

        const apiResData = await getWithToken("notification/list");

        if (apiResData.error === false) {
          setUserData(apiResData.result);
          setTotalData(apiResData.total);
        } else {
          setUserData([]);
          setTotalData(0);
        }
      }

    } catch (error) {
      console.error("Error fetching slider:", error);

    }
  };



  return (
    <DropdownMenu>
      <DropdownMenuTrigger asChild>
        <Button
          variant="ghost"
          size="icon"
          className="relative md:h-9 md:w-9 h-8 w-8 hover:bg-default-100 dark:hover:bg-default-200 
          data-[state=open]:bg-default-100  dark:data-[state=open]:bg-default-200 
           hover:text-primary text-default-500 dark:text-default-800  rounded-full "
        >
          <Envelope className="h-5 w-5 " />
          <Badge className="w-4 h-4 p-0 text-xs  font-medium  items-center justify-center absolute left-[calc(100%-18px)] bottom-[calc(100%-16px)] ring-2 ring-primary-foreground">
            {totalData}
          </Badge>
        </Button>
      </DropdownMenuTrigger>
      <DropdownMenuContent
        align="end"
        className=" z-[999] mx-4 lg:w-[412px] p-0"
      >
        <DropdownMenuLabel
          style={{ backgroundImage: `url(${""})` }}
          className="w-full h-full bg-cover bg-no-repeat p-4 flex items-center"
        >
          <span className="text-base font-semibold flex-1">
            Message
          </span>
          <Link
            href="/admin/notification/all"
            className="text-xs font-medium flex-0 hover:underline hover:decoration-default-100 dark:decoration-default-900"
          >
            View All
          </Link>
        </DropdownMenuLabel>
        <div className="h-[350px] xl:h-[420px]">
          <ScrollArea className="h-full">
            {

            data && data?.length >0 ?
            
            data.map((item, index) => (
              <DropdownMenuItem
                key={`inbox-${index}`}
                className="flex gap-9 py-2 px-4 cursor-pointer dark:hover:bg-background rounded-none"
              >
                <div className="flex-1 flex items-center gap-2">
                  <svg xmlns="http://www.w3.org/2000/svg" width="32" height="32" viewBox="0 0 36 36"><path fill="rgb(132 108 249)" d="M28 13c0 11 5 10 5 15c0 0 0 2-2 2H5c-2 0-2-2-2-2c0-5 5-4 5-15C8 7.478 12.477 3 18 3s10 4.478 10 10" /><circle cx="18" cy="3" r="3" fill="rgb(132 108 249)" /><path fill="rgb(132 108 249)" d="M18 36a4 4 0 0 0 4-4h-8a4 4 0 0 0 4 4" /></svg>
                  <div>
                    <div className="text-sm font-medium text-default-900 mb-[2px] whitespace-nowrap">
                      {item.title} ({item.type})
                    </div>
                    <div className="text-xs text-default-900 truncate max-w-[100px] lg:max-w-[185px]">
                      {" "}
                      {item.description}
                    </div>
                  </div>
                </div>
                <div
                  className={cn(
                    "text-xs font-medium text-default-900 whitespace-nowrap",
                    {
                      "text-default-600": !item.unreadmessage,
                    }
                  )}
                >
                  <p><b>{item.updatedAt.substring(0, 10)}</b></p>
                  <p><i>{item.updatedAt.substring(11, 19)}</i></p>
                  
                </div>
                
                
              </DropdownMenuItem>
            ))

            :

            <DropdownMenuItem
                key={`inbox-1`}
                className="flex gap-9 py-2 px-4 cursor-pointer dark:hover:bg-background rounded-none"
              >
                <div className="flex-1 flex items-center gap-2">
                  {/* <svg xmlns="http://www.w3.org/2000/svg" width="32" height="32" viewBox="0 0 36 36"><path fill="rgb(132 108 249)" d="M28 13c0 11 5 10 5 15c0 0 0 2-2 2H5c-2 0-2-2-2-2c0-5 5-4 5-15C8 7.478 12.477 3 18 3s10 4.478 10 10" /><circle cx="18" cy="3" r="3" fill="rgb(132 108 249)" /><path fill="rgb(132 108 249)" d="M18 36a4 4 0 0 0 4-4h-8a4 4 0 0 0 4 4" /></svg> */}
                  <div>
                    <div className="text-sm font-medium text-default-900 mb-[2px] whitespace-nowrap">
                      You are yet to receive notifications.
                    </div>
                    
                  </div>
                </div>
                
                
              </DropdownMenuItem>
          
          }
          </ScrollArea>
        </div>
      </DropdownMenuContent>
    </DropdownMenu>
  );
};

export default Inbox;
